==> riverpod-0.6.0-dev.tar.gz: lib/src/future_provider/auto_dispose.dart <==
part of '../future_provider.dart';

/// {@macro riverpod.futureprovider}
class AutoDisposeFutureProvider<T>
    extends AutoDisposeProviderBase<Future<T>, AsyncValue<T>>
    with _FutureProviderMixin<T> {
  /// {@macro riverpod.futureprovider}
  AutoDisposeFutureProvider(
    Create<Future<T>, AutoDisposeProviderReference> create, {
    String name,
  }) : super(create, name);

  /// {@macro riverpod.family}
  static const family = AutoDisposeFutureProviderFamilyBuilder();

  ProviderBase<Future<T>, Future<T>> _future;

  /// {@macro riverpod.futureprovider.future}
  ProviderBase<Future<T>, Future<T>> get future {
    return _future ??= AutoDisposeCreatedProvider(
      this,
      name: name == null ? null : '$name.future',
    );
  }

  @override
  _AutoDisposeFutureProviderState<T> createState() =>
      _AutoDisposeFutureProviderState();
}

class _AutoDisposeFutureProviderState<T> = ProviderStateBase<Future<T>,
    AsyncValue<T>> with _FutureProviderStateMixin<T>;

/// {@macro riverpod.futureprovider.family}
class AutoDisposeFutureProviderFamily<T, A> extends Family<
    Future<T>,
    AsyncValue<T>,
    A,
    AutoDisposeProviderReference,
    AutoDisposeFutureProvider<T>> {
  /// {@macro riverpod.futureprovider.family}
  AutoDisposeFutureProviderFamily(
    Future<T> Function(AutoDisposeProviderReference ref, A a) create, {
    String name,
  }) : super(create, name);

  @override
  AutoDisposeFutureProvider<T> create(
    A value,
    Future<T> Function(AutoDisposeProviderReference ref, A param) builder,
    String name,
  ) {
    return AutoDisposeFutureProvider((ref) => builder(ref, value), name: name);
  }
}

==> riverpod-0.12.3.tar.gz: lib/src/future_provider/auto_dispose.dart <==
part of '../future_provider.dart';

/// {@macro riverpod.futureprovider}
@sealed
class AutoDisposeFutureProvider<T>
    extends AutoDisposeProviderBase<Future<T>, AsyncValue<T>>
    with _FutureProviderMixin<T> {
  /// {@macro riverpod.futureprovider}
  AutoDisposeFutureProvider(
    Create<Future<T>, AutoDisposeProviderReference> create, {
    String name,
  }) : super(create, name);

  /// {@macro riverpod.family}
  static const family = AutoDisposeFutureProviderFamilyBuilder();

  RootProvider<Future<T>, Future<T>> _future;

  /// {@macro riverpod.futureprovider.future}
  RootProvider<Future<T>, Future<T>> get future {
    return _future ??= AutoDisposeCreatedProvider(
      this,
      name: name == null ? null : '$name.future',
    );
  }

  @override
  _AutoDisposeFutureProviderState<T> createState() =>
      _AutoDisposeFutureProviderState();
}

@sealed
class _AutoDisposeFutureProviderState<T> = ProviderStateBase<Future<T>,
    AsyncValue<T>> with _FutureProviderStateMixin<T>;

/// {@macro riverpod.futureprovider.family}
@sealed
class AutoDisposeFutureProviderFamily<T, A> extends Family<
    Future<T>,
    AsyncValue<T>,
    A,
    AutoDisposeProviderReference,
    AutoDisposeFutureProvider<T>> {
  /// {@macro riverpod.futureprovider.family}
  AutoDisposeFutureProviderFamily(
    Future<T> Function(AutoDisposeProviderReference ref, A a) create, {
    String name,
  }) : super(create, name);

  @override
  AutoDisposeFutureProvider<T> create(
    A value,
    Future<T> Function(AutoDisposeProviderReference ref, A param) builder,
    String name,
  ) {
    return AutoDisposeFutureProvider((ref) => builder(ref, value), name: name);
  }
}
